Module composition

Module composition 

Lua DSL 背后的作品、段落、旋律序列和采样片段构建器。 Song, phrase, sequence, and sample-clip builders used by the Lua DSL.

Structs

PulseMidiClip
A MIDI file arranged as a reusable song or phrase clip.
PulseNoteEvent
One monophonic or polyphonic sequence event.
PulsePhrase
A reusable phrase containing layered sequences and drum grids.
PulseSampleClip
A Lua-friendly sample clip that renders into offline audio exports.
PulseSequence
A Lua-friendly melodic sequence with one duration per event.
PulseSong
A Lua-friendly song container that can be converted to tunes.