pub struct PulseSequence { /* private fields */ }Expand description
A Lua-friendly melodic sequence with one duration per event.
Implementations
Sourceimpl PulseSequence
impl PulseSequence
Sourcepub fn with_notes(self, notes: Vec<f32>) -> Self
pub fn with_notes(self, notes: Vec<f32>) -> Self
Replaces the sequence note frequencies.
Sourcepub fn with_chords(self, chords: Vec<Vec<f32>>) -> Self
pub fn with_chords(self, chords: Vec<Vec<f32>>) -> Self
Replaces the sequence with polyphonic note events.
Sourcepub fn with_durations(self, durations: Vec<f32>) -> Self
pub fn with_durations(self, durations: Vec<f32>) -> Self
Replaces the sequence durations.
Sourcepub fn with_instrument(self, instrument: impl Into<String>) -> Self
pub fn with_instrument(self, instrument: impl Into<String>) -> Self
Sets the instrument alias for this sequence.
Sourcepub fn with_synth(self, synth: PulseSynth) -> Self
pub fn with_synth(self, synth: PulseSynth) -> Self
Sets an explicit synthesis algorithm for this sequence.
Sourcepub fn with_start_at(self, start_at: f32) -> PulseResult<Self>
pub fn with_start_at(self, start_at: f32) -> PulseResult<Self>
Sets a sequence start offset relative to the song or phrase placement.
Sourcepub fn with_volume(self, volume: f32) -> PulseResult<Self>
pub fn with_volume(self, volume: f32) -> PulseResult<Self>
Sets track volume for this sequence.
Sourcepub fn with_pan(self, pan: f32) -> PulseResult<Self>
pub fn with_pan(self, pan: f32) -> PulseResult<Self>
Sets stereo pan for this sequence.
Sourcepub fn with_velocity(self, velocity: f32) -> PulseResult<Self>
pub fn with_velocity(self, velocity: f32) -> PulseResult<Self>
Sets velocity for notes exported from this sequence.
Sourcepub fn transposed(&self, semitones: i32) -> Self
pub fn transposed(&self, semitones: i32) -> Self
Returns a transposed copy without mutating the original sequence.
Sourcepub fn with_effect(self, effect: PulseEffect) -> Self
pub fn with_effect(self, effect: PulseEffect) -> Self
Appends a track-level effect to the sequence.
Sourcepub fn validate(&self) -> PulseResult<()>
pub fn validate(&self) -> PulseResult<()>
Validates sequence shape and instrument name.
Sourcepub fn events(&self) -> PulseResult<Vec<PulseNoteEvent>>
pub fn events(&self) -> PulseResult<Vec<PulseNoteEvent>>
Returns note/chord events with the current durations applied.
Sourcepub fn instrument(&self) -> &str
pub fn instrument(&self) -> &str
Returns the instrument alias.
Sourcepub fn synth(&self) -> Option<&PulseSynth>
pub fn synth(&self) -> Option<&PulseSynth>
Returns the explicit synthesis algorithm, if one was selected.
Sourcepub fn effects(&self) -> &[PulseEffect]
pub fn effects(&self) -> &[PulseEffect]
Returns track-level effects in insertion order.