pub struct PulseSong { /* private fields */ }Expand description
A Lua-friendly song container that can be converted to tunes.
Implementations
Sourceimpl PulseSong
impl PulseSong
Sourcepub fn with_tempo(self, bpm: f32) -> PulseResult<Self>
pub fn with_tempo(self, bpm: f32) -> PulseResult<Self>
Sets the song tempo in beats per minute.
Sourcepub fn add_sequence(self, sequence: PulseSequence) -> Self
pub fn add_sequence(self, sequence: PulseSequence) -> Self
Appends one sequence.
Sourcepub fn add_drum_grid(self, grid: PulseDrumGrid) -> Self
pub fn add_drum_grid(self, grid: PulseDrumGrid) -> Self
Appends one drum grid.
Sourcepub fn add_phrase(self, phrase: PulsePhrase) -> Self
pub fn add_phrase(self, phrase: PulsePhrase) -> Self
Appends one reusable phrase to the song arrangement.
Sourcepub fn add_sample_clip(self, sample_clip: PulseSampleClip) -> Self
pub fn add_sample_clip(self, sample_clip: PulseSampleClip) -> Self
Appends one sample clip to the song.
Sourcepub fn add_midi_clip(self, midi_clip: PulseMidiClip) -> Self
pub fn add_midi_clip(self, midi_clip: PulseMidiClip) -> Self
Appends one imported MIDI clip to the song.
Sourcepub fn with_master_effect(self, effect: PulseEffect) -> Self
pub fn with_master_effect(self, effect: PulseEffect) -> Self
Appends a master effect to the song.
Sourcepub fn to_tunes_composition(&self) -> PulseResult<Composition>
pub fn to_tunes_composition(&self) -> PulseResult<Composition>
Converts the wrapper DSL into a tunes composition.
Sourcepub fn to_mixer(&self) -> PulseResult<Mixer>
pub fn to_mixer(&self) -> PulseResult<Mixer>
Converts the wrapper DSL into a tunes mixer and applies master effects.
Sourcepub fn sequences(&self) -> &[PulseSequence]
pub fn sequences(&self) -> &[PulseSequence]
Returns all sequences.
Sourcepub fn drum_grids(&self) -> &[PulseDrumGrid]
pub fn drum_grids(&self) -> &[PulseDrumGrid]
Returns all drum grids.
Sourcepub fn phrases(&self) -> &[PulsePhrase]
pub fn phrases(&self) -> &[PulsePhrase]
Returns all phrases.
Sourcepub fn sample_clips(&self) -> &[PulseSampleClip]
pub fn sample_clips(&self) -> &[PulseSampleClip]
Returns all sample clips.
Sourcepub fn midi_clips(&self) -> &[PulseMidiClip]
pub fn midi_clips(&self) -> &[PulseMidiClip]
Returns all imported MIDI clips.
Sourcepub fn master_effects(&self) -> &[PulseEffect]
pub fn master_effects(&self) -> &[PulseEffect]
Returns master effects in insertion order.