pub enum PulseEffect {
Delay(PulseDelay),
Reverb(PulseReverb),
Filter(PulseFilter),
Compressor(PulseCompressor),
Limiter(PulseLimiter),
Chorus(PulseChorus),
Phaser(PulsePhaser),
Eq(PulseEq),
}Expand description
One effect instance ready to apply to a track or master bus.
Variants
Delay(PulseDelay)
Delay.
Reverb(PulseReverb)
Reverb.
Filter(PulseFilter)
Filter. This is track-only.
Compressor(PulseCompressor)
Compressor.
Limiter(PulseLimiter)
Limiter.
Chorus(PulseChorus)
Chorus.
Phaser(PulsePhaser)
Phaser.
Eq(PulseEq)
Three-band EQ.
Implementations
Sourceimpl PulseEffect
impl PulseEffect
Sourcepub fn allowed_on_master(&self) -> bool
pub fn allowed_on_master(&self) -> bool
Returns whether this effect can be applied to the master bus.
Sourcepub fn apply_to_track_builder<'a>(
&self,
builder: TrackBuilder<'a>,
) -> TrackBuilder<'a>
pub fn apply_to_track_builder<'a>( &self, builder: TrackBuilder<'a>, ) -> TrackBuilder<'a>
Applies this effect to a tunes track builder.
Sourcepub fn apply_to_master(&self, mixer: &mut Mixer) -> PulseResult<()>
pub fn apply_to_master(&self, mixer: &mut Mixer) -> PulseResult<()>
Applies this effect to a tunes mixer master bus.
Errors
Returns an invalid-scope error when called for a track-only effect.