effect_from_options

Function effect_from_options 

pub fn effect_from_options(
    name: &str,
    options: EffectOptions,
) -> PulseResult<PulseEffect>
Builds an effect from a name and parsed options.

Errors

Returns an error when the name, preset, option name, or option value is invalid.