Module files

Module files 

按文件扩展名分派导出、FLAC/MIDI 辅助函数和 MIDI 导入包装。

Structs

PulseImportedMidi
A MIDI file imported into a tunes mixer.

Functions

export
Exports a song based on the output file extension.
export_flac
Exports a song to FLAC through tunes::engine::AudioEngine::export_flac.
export_flac_with_options
Exports a song to FLAC through tunes::engine::AudioEngine::export_flac with options.
export_formats
Returns the file extensions supported by export.
export_midi
Exports a song to Standard MIDI File through tunes::track::Mixer::export_midi.
export_midi_with_options
Exports a song to Standard MIDI File with explicit export options.
export_with_options
Exports a song based on the output file extension with explicit export options.
import_midi
Imports a Standard MIDI File through tunes::track::Mixer::import_midi.