pub struct PulseImportedMidi { /* private fields */ }Expand description
A MIDI file imported into a tunes mixer.
Implementations
Sourceimpl PulseImportedMidi
impl PulseImportedMidi
Sourcepub fn as_clip(&self) -> PulseMidiClip
pub fn as_clip(&self) -> PulseMidiClip
Returns this imported MIDI file as an arrangeable song or phrase clip.
Sourcepub fn export(&self, path: impl AsRef<Path>) -> PulseResult<()>
pub fn export(&self, path: impl AsRef<Path>) -> PulseResult<()>
Exports the imported MIDI mixer based on the output file extension.
Sourcepub fn export_with_options(
&self,
path: impl AsRef<Path>,
options: ExportOptions,
) -> PulseResult<()>
pub fn export_with_options( &self, path: impl AsRef<Path>, options: ExportOptions, ) -> PulseResult<()>
Exports the imported MIDI mixer based on the output file extension with options.
Sourcepub fn export_wav(&self, path: impl AsRef<Path>) -> PulseResult<()>
pub fn export_wav(&self, path: impl AsRef<Path>) -> PulseResult<()>
Exports the imported MIDI mixer to WAV.
Sourcepub fn export_wav_with_options(
&self,
path: impl AsRef<Path>,
options: ExportOptions,
) -> PulseResult<()>
pub fn export_wav_with_options( &self, path: impl AsRef<Path>, options: ExportOptions, ) -> PulseResult<()>
Exports the imported MIDI mixer to WAV with explicit export options.
Sourcepub fn export_flac(&self, path: impl AsRef<Path>) -> PulseResult<()>
pub fn export_flac(&self, path: impl AsRef<Path>) -> PulseResult<()>
Exports the imported MIDI mixer to FLAC.
Sourcepub fn export_flac_with_options(
&self,
path: impl AsRef<Path>,
options: ExportOptions,
) -> PulseResult<()>
pub fn export_flac_with_options( &self, path: impl AsRef<Path>, options: ExportOptions, ) -> PulseResult<()>
Exports the imported MIDI mixer to FLAC with explicit export options.
Sourcepub fn export_midi(&self, path: impl AsRef<Path>) -> PulseResult<()>
pub fn export_midi(&self, path: impl AsRef<Path>) -> PulseResult<()>
Exports the imported MIDI mixer to a Standard MIDI File.
Sourcepub fn export_midi_with_options(
&self,
path: impl AsRef<Path>,
options: ExportOptions,
) -> PulseResult<()>
pub fn export_midi_with_options( &self, path: impl AsRef<Path>, options: ExportOptions, ) -> PulseResult<()>
Exports the imported MIDI mixer to a Standard MIDI File with explicit export options.