normalize_values

Function normalize_values 

pub fn normalize_values(
    values: &[f32],
    min: f32,
    max: f32,
) -> PulseResult<Vec<f32>>
Normalizes finite values into the requested floating point range.

Errors

Returns an invalid generator option error when the input is empty, contains non-finite values, or the target range is invalid.