pub struct GeneratorOptions { /* private fields */ }Expand description
Generator options parsed from a Lua table.
Implementations
Sourceimpl GeneratorOptions
impl GeneratorOptions
Sourcepub fn insert(&mut self, name: impl Into<String>, value: GeneratorOption)
pub fn insert(&mut self, name: impl Into<String>, value: GeneratorOption)
Inserts or replaces one named option.
Sourcepub fn required_usize(&self, name: &str) -> PulseResult<usize>
pub fn required_usize(&self, name: &str) -> PulseResult<usize>
Reads a required positive usize option.
Errors
Returns an error when the option is missing, non-integer, zero, or too large.
Sourcepub fn usize_or(&self, name: &str, default: usize) -> PulseResult<usize>
pub fn usize_or(&self, name: &str, default: usize) -> PulseResult<usize>
Reads an optional positive usize option.
Errors
Returns an error when the supplied option is non-integer, zero, or too large.
Sourcepub fn required_u32(&self, name: &str) -> PulseResult<u32>
pub fn required_u32(&self, name: &str) -> PulseResult<u32>
Reads a required non-negative u32 option.
Errors
Returns an error when the option is missing, negative, non-integer, or too large.
Sourcepub fn u32_or(&self, name: &str, default: u32) -> PulseResult<u32>
pub fn u32_or(&self, name: &str, default: u32) -> PulseResult<u32>
Reads an optional non-negative u32 option.
Errors
Returns an error when the supplied option is negative, non-integer, or too large.
Sourcepub fn f32_or(&self, name: &str, default: f32) -> PulseResult<f32>
pub fn f32_or(&self, name: &str, default: f32) -> PulseResult<f32>
Reads an optional finite f32 option.
Errors
Returns an error when the supplied option is not numeric or not finite.
Sourcepub fn required_f32(&self, name: &str) -> PulseResult<f32>
pub fn required_f32(&self, name: &str) -> PulseResult<f32>
Reads a required finite f32 option.
Errors
Returns an error when the option is missing, not numeric, or not finite.
Sourcepub fn required_text(&self, name: &str) -> PulseResult<&str>
pub fn required_text(&self, name: &str) -> PulseResult<&str>
Sourcepub fn required_text_map(
&self,
name: &str,
) -> PulseResult<&BTreeMap<String, String>>
pub fn required_text_map( &self, name: &str, ) -> PulseResult<&BTreeMap<String, String>>
Reads a required string-to-string map option.
Errors
Returns an error when the option is missing or not a text map.