mixer_from_playable

Function mixer_from_playable 

pub fn mixer_from_playable(playable: PulsePlayable<'_>) -> PulseResult<Mixer>
Converts a playback target into a fresh tunes mixer.

Errors

Returns an error when the source song cannot be converted to a mixer.