PulsePlaybackEngine

Struct PulsePlaybackEngine 

pub struct PulsePlaybackEngine { /* private fields */ }
Shared playback engine used by Lua playback handles.

Implementations

Source

impl PulsePlaybackEngine

pub fn new() -> PulseResult<Self>

Creates a playback engine using tunes::engine::AudioEngine::new.

Errors

Returns a playback error when the audio engine cannot initialize.

pub fn play(&self, playable: PulsePlayable<'_>) -> PulseResult<()>

Plays a target immediately and waits for tunes to schedule playback.

Errors

Returns an error when mixer creation or playback scheduling fails.

pub fn play_realtime( &self, playable: PulsePlayable<'_>, ) -> PulseResult<PulsePlaybackHandle>

Starts real-time playback and returns a handle for later control.

Errors

Returns an error when mixer creation or playback scheduling fails.

pub fn play_looping( &self, playable: PulsePlayable<'_>, ) -> PulseResult<PulsePlaybackHandle>

Starts looping playback and returns a handle for later control.

Errors

Returns an error when mixer creation or playback scheduling fails.

pub fn play_at_rate( &self, playable: PulsePlayable<'_>, rate: f32, ) -> PulseResult<()>

Plays a target with a playback-rate multiplier.

Errors

Returns an error when rate is invalid or playback fails.

pub fn play_realtime_at_rate( &self, playable: PulsePlayable<'_>, rate: f32, ) -> PulseResult<PulsePlaybackHandle>

Starts real-time playback with a playback-rate multiplier.

Errors

Returns an error when rate is invalid or playback fails.