pub struct PulsePlaybackHandle { /* private fields */ }Expand description
Handle for a real-time or looping sound started by PulsePlaybackEngine.
Implementations
Sourceimpl PulsePlaybackHandle
impl PulsePlaybackHandle
Sourcepub fn from_parts(engine: Rc<AudioEngine>, sound_id: SoundId) -> Self
pub fn from_parts(engine: Rc<AudioEngine>, sound_id: SoundId) -> Self
Creates a handle from an engine reference and tunes sound identifier.
Sourcepub fn stop(&self) -> PulseResult<Self>
pub fn stop(&self) -> PulseResult<Self>
Stops playback and returns a cloned handle for Lua chainability.
Errors
Returns an error when the engine rejects the stop request.
Sourcepub fn volume(&self, volume: f32) -> PulseResult<Self>
pub fn volume(&self, volume: f32) -> PulseResult<Self>
Sets playback volume and returns a cloned handle for Lua chainability.
Errors
Returns an error when volume is invalid or the engine rejects the request.
Sourcepub fn pan(&self, pan: f32) -> PulseResult<Self>
pub fn pan(&self, pan: f32) -> PulseResult<Self>
Sets playback stereo pan and returns a cloned handle for Lua chainability.
Errors
Returns an error when pan is invalid or the engine rejects the request.
Sourcepub fn rate(&self, rate: f32) -> PulseResult<Self>
pub fn rate(&self, rate: f32) -> PulseResult<Self>
Sets playback rate and returns a cloned handle for Lua chainability.
Errors
Returns an error when rate is invalid or the engine rejects the request.
Sourcepub fn pause(&self) -> PulseResult<Self>
pub fn pause(&self) -> PulseResult<Self>
Pauses playback and returns a cloned handle for Lua chainability.
Errors
Returns an error when the engine rejects the pause request.
Sourcepub fn resume(&self) -> PulseResult<Self>
pub fn resume(&self) -> PulseResult<Self>
Resumes playback and returns a cloned handle for Lua chainability.
Errors
Returns an error when the engine rejects the resume request.