pub struct PulsePhrase { /* private fields */ }Expand description
A reusable phrase containing layered sequences and drum grids.
Implementations
Sourceimpl PulsePhrase
impl PulsePhrase
Sourcepub fn add_sequence(self, sequence: PulseSequence) -> Self
pub fn add_sequence(self, sequence: PulseSequence) -> Self
Appends one melodic sequence to this phrase.
Sourcepub fn add_drum_grid(self, grid: PulseDrumGrid) -> Self
pub fn add_drum_grid(self, grid: PulseDrumGrid) -> Self
Appends one drum grid to this phrase.
Sourcepub fn add_sample_clip(self, sample_clip: PulseSampleClip) -> Self
pub fn add_sample_clip(self, sample_clip: PulseSampleClip) -> Self
Appends one sample clip to this phrase.
Sourcepub fn add_midi_clip(self, midi_clip: PulseMidiClip) -> Self
pub fn add_midi_clip(self, midi_clip: PulseMidiClip) -> Self
Appends one imported MIDI clip to this phrase.
Sourcepub fn with_repeat_times(self, repeat_times: usize) -> PulseResult<Self>
pub fn with_repeat_times(self, repeat_times: usize) -> PulseResult<Self>
Sets how many total times the phrase should play.
Sourcepub fn duration(&self) -> PulseResult<f32>
pub fn duration(&self) -> PulseResult<f32>
Returns phrase duration for one play-through.
Sourcepub fn total_duration(&self) -> PulseResult<f32>
pub fn total_duration(&self) -> PulseResult<f32>
Returns phrase duration including repeats.
Sourcepub fn sequences(&self) -> &[PulseSequence]
pub fn sequences(&self) -> &[PulseSequence]
Returns all melodic sequences.
Sourcepub fn drum_grids(&self) -> &[PulseDrumGrid]
pub fn drum_grids(&self) -> &[PulseDrumGrid]
Returns all drum grids.
Sourcepub fn sample_clips(&self) -> &[PulseSampleClip]
pub fn sample_clips(&self) -> &[PulseSampleClip]
Returns all sample clips.
Sourcepub fn midi_clips(&self) -> &[PulseMidiClip]
pub fn midi_clips(&self) -> &[PulseMidiClip]
Returns all imported MIDI clips.
Sourcepub fn repeat_times(&self) -> usize
pub fn repeat_times(&self) -> usize
Returns how many total times this phrase plays.