按文件扩展名分派导出、FLAC/MIDI 辅助函数和 MIDI 导入包装。
Structs
- Pulse
Imported Midi - A MIDI file imported into a
tunesmixer.
Functions
- export
- Exports a song based on the output file extension.
- export_
flac - Exports a song to FLAC through
tunes::engine::AudioEngine::export_flac. - export_
flac_ with_ options - Exports a song to FLAC through
tunes::engine::AudioEngine::export_flacwith options. - export_
formats - Returns the file extensions supported by
export. - export_
midi - Exports a song to Standard MIDI File through
tunes::track::Mixer::export_midi. - export_
midi_ with_ options - Exports a song to Standard MIDI File with explicit export options.
- export_
with_ options - Exports a song based on the output file extension with explicit export options.
- import_
midi - Imports a Standard MIDI File through
tunes::track::Mixer::import_midi.