pub fn mixer_from_playable(playable: PulsePlayable<'_>) -> PulseResult<Mixer>Expand description
Converts a playback target into a fresh tunes mixer.
Errors
Returns an error when the source song cannot be converted to a mixer.
pub fn mixer_from_playable(playable: PulsePlayable<'_>) -> PulseResult<Mixer>Converts a playback target into a fresh tunes mixer.
Returns an error when the source song cannot be converted to a mixer.