pub struct PulsePlaybackEngine { /* private fields */ }Expand description
Shared playback engine used by Lua playback handles.
Implementations
Sourceimpl PulsePlaybackEngine
impl PulsePlaybackEngine
Sourcepub fn new() -> PulseResult<Self>
pub fn new() -> PulseResult<Self>
Creates a playback engine using tunes::engine::AudioEngine::new.
Errors
Returns a playback error when the audio engine cannot initialize.
Sourcepub fn play(&self, playable: PulsePlayable<'_>) -> PulseResult<()>
pub fn play(&self, playable: PulsePlayable<'_>) -> PulseResult<()>
Plays a target immediately and waits for tunes to schedule playback.
Errors
Returns an error when mixer creation or playback scheduling fails.
Sourcepub fn play_realtime(
&self,
playable: PulsePlayable<'_>,
) -> PulseResult<PulsePlaybackHandle>
pub fn play_realtime( &self, playable: PulsePlayable<'_>, ) -> PulseResult<PulsePlaybackHandle>
Starts real-time playback and returns a handle for later control.
Errors
Returns an error when mixer creation or playback scheduling fails.
Sourcepub fn play_looping(
&self,
playable: PulsePlayable<'_>,
) -> PulseResult<PulsePlaybackHandle>
pub fn play_looping( &self, playable: PulsePlayable<'_>, ) -> PulseResult<PulsePlaybackHandle>
Starts looping playback and returns a handle for later control.
Errors
Returns an error when mixer creation or playback scheduling fails.
Sourcepub fn play_at_rate(
&self,
playable: PulsePlayable<'_>,
rate: f32,
) -> PulseResult<()>
pub fn play_at_rate( &self, playable: PulsePlayable<'_>, rate: f32, ) -> PulseResult<()>
Plays a target with a playback-rate multiplier.
Errors
Returns an error when rate is invalid or playback fails.
Sourcepub fn play_realtime_at_rate(
&self,
playable: PulsePlayable<'_>,
rate: f32,
) -> PulseResult<PulsePlaybackHandle>
pub fn play_realtime_at_rate( &self, playable: PulsePlayable<'_>, rate: f32, ) -> PulseResult<PulsePlaybackHandle>
Starts real-time playback with a playback-rate multiplier.
Errors
Returns an error when rate is invalid or playback fails.